@@ -9,7 +9,7 @@ BEGIN
 {
 use vars qw ($VERSION @EXPORT_OK %EXPORT_TAGS);
 
-$VERSION     = '0.4' ;
+$VERSION     = 0.01;
 @EXPORT_OK   = qw (IsDebuggerEnabled CheckBreakpoint);
 %EXPORT_TAGS = ();
 }
@@ -19,20 +19,18 @@ $VERSION     = '0.4' ;
 use Carp qw(croak carp confess cluck);
 use Data::TreeDumper ;
 
-use Sub::Install;
 use English qw( -no_match_vars ) ;
 
 use Readonly ;
 Readonly my $EMPTY_STRING => q{} ;
 
 use Tie::Hash::Indexed ;
-use List::MoreUtils qw(any) ;
 
 #-------------------------------------------------------------------------------
 
 =head1 NAME
 
- Debug::Mixin - Make your applications and modules easier to debug
+ Debug::App - Make your applications and modules easier to debug
 
 =head1 SYNOPSIS
 
@@ -211,11 +209,11 @@ script doesn't have to be aware of modules debugging facilities, only modules us
 
 if(*DB::DB{CODE})
 	{
-	Output("Debug::Mixin support available, type 'dm_help' for help, or man Debug::Mixin for more help.\n\n") ;
+	print "Debug::Mixin support available, type 'dm_help' for help, or man Debug::Mixin for more help.\n\n" ;
 	}
 else
 	{
-	Output("Debug::Mixin banner when debugger is not loaded\n") ;
+	print "Debug::Mixin banner when debugger is not loaded\n" ;
 	}
 	
 #-------------------------------------------------------------------------------
@@ -235,14 +233,14 @@ Called for you by Perl
 
 =cut
 
-my ($module_name, $data, @more_data) = @_ ;
-
 my ($package, $file_name, $line) = caller() ;
-Output("Debug::Mixin used at '$package, $file_name, $line'\n") ;
+print "Debug::Mixin used at '$package, $file_name, $line'\n" ;
 
 #~ use Data::TreeDumper ;
 #~ print DumpTree \@_ ;
 
+my ($module_name, $data, @more_data) = @_ ;
+
 if(defined $data)
 	{
 	if('HASH' eq ref $data)
@@ -257,7 +255,7 @@ if(defined $data)
 		unshift @more_data, $data ;
 		for(@more_data)
 			{
-			SetupElement($package, $file_name, $line, split(/=/sxm, $_)) ;
+			SetupElement($package, $file_name, $line, split(/=/xm, $_)) ;
 			}
 		}
 	}
@@ -268,7 +266,7 @@ if(defined $data)
 #except
 if(*DB::DB{CODE})
 	{
-	
+	use Sub::Install;
 	
 	for my $sub
 		(
@@ -314,50 +312,50 @@ my ($package, $file_name, $line, $key, $value) = @_ ;
 
 for($key)
 	{
-	/BANNER/smix and do
+	/BANNER/mix and do
 		{
 		if(*DB::DB{CODE})
 			{
-			Output("Debug::Mixin loaded for '$value'\n") ;
+			print "Debug::Mixin loaded for '$value'\n" ;
 			}
 		next ;
 		} ;
 		
-	/LoadBreakpointsFiles/smx and do
+	/LoadBreakpointsFiles/mx and do
 		{
 		my $files = 'ARRAY' eq ref $value ? $value : [$value] ;
 		
 		for my $file (@{$files})
 			{
-			Output("Loading '$file'\n") ;
+			print "Loading '$file'\n" ;
 			}
 		next ;
 		} ;
 		
-	/DEBUGGER_SUBS/smx and do
+	/DEBUGGER_SUBS/mx and do
 		{
-		croak "Debug::Mixin: DEBUGGER_SUBS must be a list!\n" unless('ARRAY' eq ref $value) ;
-		croak "Debug::Mixin: no subroutine defined in DEBUGGER_SUBS!\n" if( @{$value} <= 0) ;
+		croak "Debug::Mixin: DEBUGGER_SUBS must be a list!\n" unless 'ARRAY' eq ref $value ;
+		croak "Debug::Mixin: no subroutine defined in DEBUGGER_SUBS!\n" unless @{$value} > 0 ;
 		
-		Readonly my $EXPECTED_NUMBER_OF_DEBUGGER_SUB_FIELDS => 5 ;
 		
 		for my $debugger_sub (@{$value})
 			{
 			croak "Debug::Mixin: local subroutine must be a hash!\n" unless 'HASH' eq ref $debugger_sub ;
-			croak "Debug::Mixin: invalid local subroutine definition!\n" 
-				unless $EXPECTED_NUMBER_OF_DEBUGGER_SUB_FIELDS	== keys %{$debugger_sub} ;
+			croak "Debug::Mixin: invalid local subroutine definition!\n" unless 5 == keys %{$debugger_sub} ;
 			
 			my $valid_keys = join('$|^', qw(NAME ALIASES DESCRIPTION HELP SUB)) ; ## no critic
 			
 			for my $key (keys %{$debugger_sub})
 				{
-				croak "Debug::Mixin: Unrecognized local subroutine argument '$key'!\n" unless $key =~ /^$valid_keys$/smxo ;
+				croak "Debug::Mixin: Unrecognized local subroutine argument '$key'!\n" unless $key =~ /^$valid_keys$/mxo ;
 				}
 				
 			if(*DB::DB{CODE})
 				{
 				$debugger_subs{$package}{$debugger_sub->{NAME}} = $debugger_sub ;
 				
+				use Sub::Install;
+				
 				Sub::Install::reinstall_sub
 					({
 					code => $debugger_sub->{SUB},
@@ -375,7 +373,7 @@ for($key)
 						});
 					}
 					
-				Output("Debug::Mixin registrating debugger sub '${package}::$debugger_sub->{NAME}'\n") ;
+				print "Debug::Mixin registrating debugger sub '${package}::$debugger_sub->{NAME}'\n" ;
 				}
 			}
 			
@@ -425,7 +423,7 @@ return($debug_enabled) ;
 
 #-------------------------------------------------------------------------------
 
-sub AddBreakpoint ## no critic (Subroutines::RequireArgUnpacking)
+sub AddBreakpoint
 {
 
 =head2 AddBreakpoint
@@ -547,7 +545,61 @@ croak 'AddBreakpoint: odd number of arguments!' if @_ % 2 ;
 
 my (%breakpoint) = @_ ;
 
-CheckBreakPointDefinitions(\%breakpoint) ;
+my $valid_keys = join('$|^', qw(NAME FILTERS ACTIONS DEBUGGER_SUBS LOCAL_STORAGE ALWAYS_USE_DEBUGGER ACTIVE)) ; ## no critic
+
+for my $key (keys %breakpoint)
+	{
+	croak "AddBreakpoint: Unrecognized argument '$key'!\n" unless $key =~ /^$valid_keys$/mox ;
+	}
+
+croak "AddBreakpoint: Missing NAME!\n" unless exists $breakpoint{NAME} && defined $breakpoint{NAME} ;
+croak "AddBreakpoint: NAME must be a scalar!\n" unless $EMPTY_STRING eq ref $breakpoint{NAME} ;
+
+if(exists $breakpoint{ACTIONS})
+	{
+	croak "AddBreakpoint: ACTIONS must be a list of subs!\n" unless 'ARRAY' eq ref $breakpoint{ACTIONS} ;
+	croak "AddBreakpoint: no actions defined in ACTIONS!\n" unless  @{$breakpoint{ACTIONS}} > 0 ;
+	croak "AddBreakpoint: actions is not a sub reference!\n"  if grep {'CODE' ne ref $_} @{$breakpoint{ACTIONS}} ;
+	}
+
+if(exists  $breakpoint{FILTERS})
+	{
+	croak "AddBreakpoint: FILTERS must be an array!\n" unless 'ARRAY' eq ref $breakpoint{FILTERS} ;
+	croak "AddBreakpoint: no filters defined in FILTERS!\n" unless @{$breakpoint{FILTERS}} > 0 ;
+	croak "AddBreakpoint: filter is not a code ref!\n"  if grep {'CODE' ne ref $_} @{$breakpoint{FILTERS}} ;
+	}
+	
+unless
+	(
+	exists $breakpoint{ACTIONS} 
+	||
+	(exists $breakpoint{FILTERS} && exists $breakpoint{ALWAYS_USE_DEBUGGER} && $breakpoint{ALWAYS_USE_DEBUGGER} == 1)
+	)
+	{
+	croak "AddBreakpoint: Missing ACTIONS or (FILTERS + ALWAYS_USE_DEBUGGER)!\n" 
+	}
+
+if(exists $breakpoint{DEBUGGER_SUBS})
+	{
+	croak "AddBreakpoint: DEBUGGER_SUBS must be a list!\n" unless 'ARRAY' eq ref $breakpoint{DEBUGGER_SUBS} ;
+	croak "AddBreakpoint: no subroutine defined in DEBUGGER_SUBS!\n" unless @{$breakpoint{DEBUGGER_SUBS}} > 0 ;
+	
+	for my $debugger_sub (@{$breakpoint{DEBUGGER_SUBS}})
+		{
+		croak "AddBreakpoint: local subroutine must be a hash!\n" unless 'HASH' eq ref $debugger_sub ;
+		croak "AddBreakpoint: invalid local subroutine definition!\n" unless  4 == keys %{$debugger_sub} ;
+		
+		my $valid_function_keys = join('$|^', qw(NAME DESCRIPTION HELP SUB)) ; ## no critic
+		
+		for my $key (keys %{$debugger_sub})
+			{
+			croak "AddBreakpoint: Unrecognized local subroutine argument '$key'!\n" unless $key =~ /^$valid_function_keys$/mox ;
+			}
+		}
+	}
+	
+croak "AddBreakpoint: ALWAYS_USE_DEBUGGER must be a scalar!\n" if exists $breakpoint{ALWAYS_USE_DEBUGGER}&& $EMPTY_STRING ne ref $breakpoint{ALWAYS_USE_DEBUGGER} ;
+croak "AddBreakpoint: ACTIVE must be a scalar!\n" if exists $breakpoint{ACTIVE}&& $EMPTY_STRING ne  ref $breakpoint{ACTIVE} ;
 
 my ($package, $file_name, $line) = caller() ;
 
@@ -573,81 +625,6 @@ return(1) ;
 
 #----------------------------------------------------------------------
 
-sub CheckBreakPointDefinitions
-{## no critic (ProhibitExcessComplexity)
-
-=head2 CheckBreakPointDefinitions
-
-Checks the validity of the user supplied breakpoint definitions. Croaks on error.
-
-=cut
-
-my ($breakpoint) = @_ ;
-
-my $valid_keys = join('$|^', qw(NAME FILTERS ACTIONS DEBUGGER_SUBS LOCAL_STORAGE ALWAYS_USE_DEBUGGER ACTIVE)) ; ## no critic
-
-for my $key (keys %{$breakpoint})
-	{
-	croak "AddBreakpoint: Unrecognized argument '$key'!\n" unless $key =~ /^$valid_keys$/smox ;
-	}
-
-croak "AddBreakpoint: Missing NAME!\n" unless exists $breakpoint->{NAME} && defined $breakpoint->{NAME} ;
-croak "AddBreakpoint: NAME must be a scalar!\n" unless $EMPTY_STRING eq ref $breakpoint->{NAME} ;
-
-if(exists $breakpoint->{ACTIONS})
-	{
-	croak "AddBreakpoint: ACTIONS must be a list of subs!\n" unless 'ARRAY' eq ref $breakpoint->{ACTIONS} ;
-	croak "AddBreakpoint: no actions defined in ACTIONS!\n" if  @{$breakpoint->{ACTIONS}} <= 0 ;
-	croak "AddBreakpoint: actions is not a sub reference!\n"  if any {'CODE' ne ref $_} @{$breakpoint->{ACTIONS}} ;
-	}
-
-if(exists  $breakpoint->{FILTERS})
-	{
-	croak "AddBreakpoint: FILTERS must be an array!\n" unless 'ARRAY' eq ref $breakpoint->{FILTERS} ;
-	croak "AddBreakpoint: no filters defined in FILTERS!\n" if @{$breakpoint->{FILTERS}} <= 0 ;
-	croak "AddBreakpoint: filter is not a code ref!\n"  if any {'CODE' ne ref $_} @{$breakpoint->{FILTERS}} ;
-	}
-	
-unless
-	(
-	exists $breakpoint->{ACTIONS} 
-	||
-	(exists $breakpoint->{FILTERS} && exists $breakpoint->{ALWAYS_USE_DEBUGGER} && $breakpoint->{ALWAYS_USE_DEBUGGER} == 1)
-	)
-	{
-	croak "AddBreakpoint: Missing ACTIONS or (FILTERS + ALWAYS_USE_DEBUGGER)!\n" 
-	}
-
-if(exists $breakpoint->{DEBUGGER_SUBS})
-	{
-	croak "AddBreakpoint: DEBUGGER_SUBS must be a list!\n" unless 'ARRAY' eq ref $breakpoint->{DEBUGGER_SUBS} ;
-	croak "AddBreakpoint: no subroutine defined in DEBUGGER_SUBS!\n" if @{$breakpoint->{DEBUGGER_SUBS}} <= 0 ;
-	
-	Readonly my $EXPECTED_NUMBER_OF_DEBUGGER_SUB_FIELDS => 4 ;
-	
-	for my $debugger_sub (@{$breakpoint->{DEBUGGER_SUBS}})
-		{
-		croak "AddBreakpoint: local subroutine must be a hash!\n" unless 'HASH' eq ref $debugger_sub ;
-		croak "AddBreakpoint: invalid local subroutine definition!\n" 
-			unless  $EXPECTED_NUMBER_OF_DEBUGGER_SUB_FIELDS == keys %{$debugger_sub} ;
-		
-		my $valid_function_keys = join('$|^', qw(NAME DESCRIPTION HELP SUB)) ; ## no critic
-		
-		for my $key (keys %{$debugger_sub})
-			{
-			croak "AddBreakpoint: Unrecognized local subroutine argument '$key'!\n" unless $key =~ /^$valid_function_keys$/smox ;
-			}
-		}
-	}
-	
-croak "AddBreakpoint: ALWAYS_USE_DEBUGGER must be a scalar!\n" if exists $breakpoint->{ALWAYS_USE_DEBUGGER}&& $EMPTY_STRING ne ref $breakpoint->{ALWAYS_USE_DEBUGGER} ;
-croak "AddBreakpoint: ACTIVE must be a scalar!\n" if exists $breakpoint->{ACTIVE}&& $EMPTY_STRING ne  ref $breakpoint->{ACTIVE} ;
-
-return ;
-}
-
-#----------------------------------------------------------------------
-
 sub LoadBreakpointsFiles
 {
 
@@ -734,7 +711,7 @@ return(1) ;
 
 sub ListDebuggerSubs
 {
-
+	
 =head2 ListDebuggerSubs
 
 List all the debugger subs registered by modules loading Debug::Mixin on STDOUT.
@@ -750,7 +727,7 @@ unless(@packages)
 	
 for my $package(@packages)
 	{
-	Output(DumpTree($debugger_subs{$package}, "$package:")) ;
+	print(DumpTree($debugger_subs{$package}, "$package:")) ;
 	}
 
 return(1) ;
@@ -760,7 +737,7 @@ return(1) ;
 
 sub ListBreakpoints
 {
-
+	
 =head2 ListBreakpoints
 
 List, on STDOUT, all the breakpoints matching the name regex passed as argument.
@@ -768,13 +745,13 @@ List, on STDOUT, all the breakpoints matching the name regex passed as argument.
 =cut
 
 my ($breakpoint_regex) = @_ ;
-$breakpoint_regex = qr/./sxm unless defined $breakpoint_regex ;
+$breakpoint_regex = qr/./ unless defined $breakpoint_regex ;
 
 for my $breakpoint_name (sort keys %breakpoints)
 	{
 	if($breakpoint_name =~ $breakpoint_regex)
 		{
-		Output(DumpTree($breakpoints{$breakpoint_name}, "$breakpoint_name:")) ;
+		print(DumpTree($breakpoints{$breakpoint_name}, "$breakpoint_name:")) ;
 		}
 	}
 
@@ -785,7 +762,7 @@ return(1) ;
 
 sub GetBreakpoints
 {
-
+	
 =head2 GetBreakpoints
 
 Returns a reference to all the breakpoints. Elements are returned in the insertion order.
@@ -835,7 +812,7 @@ return($activated_breakpoints) ;
 
 sub DeactivateBreakpoints
 {
-
+	
 =head2 DeactivateBreakpoints
 
 Deactivate all the breakpoints matching the name regex passed as argument.
@@ -867,7 +844,7 @@ return($deactivated_breakpoints) ;
 
 sub ActivateAlwaysUseDebugger
 {
-
+	
 =head2 ActivateAlwaysUseDebugger
 
 Sets all breakpoints matching the name regex passed as argument to always jumps to the perl debugger.
@@ -897,7 +874,7 @@ return($always_use_debugger_breakpoints) ;
 
 sub DeactivateAlwaysUseDebugger
 {
-
+	
 =head2 DeactivateAlwaysUseDebugger
 
 Sets all breakpoints matching the name regex passed as argument, to never jumps to the perl debugger.
@@ -925,7 +902,7 @@ return($never_use_debugger_breakpoints) ;
 
 #----------------------------------------------------------------------
 
-sub CheckBreakpoints ## no critic (Subroutines::RequireArgUnpacking)
+sub CheckBreakpoints
 {
 
 =head2 CheckBreakpoints
@@ -1094,7 +1071,7 @@ do
 	{
 	my $header = "Debug::Mixin: Available subs at breakpoint '$breakpoint->{NAME}' ($breakpoint->{MATCHED}):" ;
 	my $separator = q{-} x length $header ;
-	Output("$separator\n$header\n$separator\n") ;
+	print "$separator\n$header\n$separator\n" ;
 
 	my $index = 0 ;
 
@@ -1106,19 +1083,19 @@ do
 
 	for my $sub (@{$breakpoint->{DEBUGGER_SUBS}})
 		{
-		Output(sprintf("   #%2d %${max_length}s => $sub->{DESCRIPTION}\n", $index, $sub->{NAME})) ;
+		printf "   #%2d %${max_length}s => $sub->{DESCRIPTION}\n", $index, $sub->{NAME} ;
 		$index++ ;
 		}
 		
-	Output("\n'#' to run sub, 'd #' for a long descriptions of the sub or 'c' to continue.\n") ;
-	Output(q{>}) ;
+	print "\n'#' to run sub, 'd #' for a long descriptions of the sub or 'c' to continue.\n" ;
+	print q{>} ;
 	
-	$choice = <> ;
+	$choice = <STDIN> ;
 	chomp($choice) ;
 	
 	for($choice)
 		{
-		/^[0-9]+$/smx and do
+		/^[0-9]+$/mx and do
 			{
 			if($choice < @{$breakpoint->{DEBUGGER_SUBS}})
 				{
@@ -1135,7 +1112,7 @@ do
 			last ;
 			} ;
 			
-		/^d ([0-9]+)$/smx and do
+		/^d ([0-9]+)$/mx and do
 			{
 			my $sub_index = $1 ; ## no critic
 			
@@ -1146,7 +1123,7 @@ do
 				my $sub_header = "$sub->{NAME}:" ;
 				my $sub_separator = q{-} x length($sub_header) ;
 				
-				Output("$sub_header\n$sub_separator\n$sub->{HELP}\n\n") ;
+				print "$sub_header\n$sub_separator\n$sub->{HELP}\n\n" ;
 				}
 				
 			last ;
@@ -1169,7 +1146,7 @@ Displays the commands made available by B<Debug::Mixin> in the debugger.
 
 =cut
 
-Output(<<'EOC') ;
+print <<'EOC' ;
 	dm_subs                     list and run debugging subs
 	
 	dm_load @files              load breakpoints files
@@ -1204,7 +1181,7 @@ do
 	{
 	my $header = 'Debug::Mixin: Available subs:' ;
 	my $separator = q{-} x length $header ;
-	Output("$separator\n$header\n$separator\n") ;
+	print "$separator\n$header\n$separator\n" ;
 	
 	my $index = 0 ;
 	my $max_length = 0 ;
@@ -1212,28 +1189,28 @@ do
 	
 	for my $package (keys %debugger_subs)
 		{
-		Output("$package:\n") ;
+		print "$package:\n" ;
 		
 		for my $sub (values %{$debugger_subs{$package}})
 			{
 			push @subs, $sub ;
 			
-			Output(sprintf("   #%2d $sub->{NAME} => $sub->{DESCRIPTION}\n", $index)) ;
+			printf "   #%2d $sub->{NAME} => $sub->{DESCRIPTION}\n", $index ;
 			$index++ ;
 			}
 			
-		Output("\n") ;
+		print "\n" ;
 		}
 		
-	Output("\n'#' to run sub, 'd #' for a long descriptions of the sub or 'c' to continue.\n") ;
-	Output(q{>}) ;
+	print "\n'#' to run sub, 'd #' for a long descriptions of the sub or 'c' to continue.\n" ;
+	print q{>} ;
 	
-	$choice = <> ;
+	$choice = <STDIN> ;
 	chomp($choice) ;
 	
 	for($choice)
 		{
-		/^[0-9]+$/smx and do
+		/^[0-9]+$/mx and do
 			{
 			if($choice < @subs)
 				{
@@ -1245,7 +1222,7 @@ do
 			last ;
 			} ;
 			
-		/^d ([0-9]+)$/smx and do
+		/^d ([0-9]+)$/mx and do
 			{
 			my $sub_index = $1 ; ## no critic
 			
@@ -1256,7 +1233,7 @@ do
 				my $sub_header = "$sub->{NAME}:" ;
 				my $sub_separator = q{-} x length($sub_header) ;
 				
-				Output("$sub_header\n$sub_separator\n$sub->{HELP}\n\n") ;
+				print "$sub_header\n$sub_separator\n$sub->{HELP}\n\n" ;
 				}
 				
 			last ;
@@ -1271,21 +1248,6 @@ return(1) ;
 
 #-------------------------------------------------------------------------------
 
-sub Output ## no critic (Subroutines::RequireArgUnpacking)
-{
-
-=head2 Output
-
-Prints the passed arguments 
-
-=cut
-
-print(@_) or die "Can't output!\n" ;
-
-return ;
-}
-
-#-------------------------------------------------------------------------------
 1 ;
 
 =head1 TO DO
@@ -1311,7 +1273,7 @@ it and/or modify it under the same terms as Perl itself.
 
 You can find documentation for this module with the perldoc command.
 
-    perldoc Debug::Mixin
+    perldoc Debug::App
 
 You can also look for information at:
 
@@ -1319,18 +1281,18 @@ You can also look for information at:
 
 =item * AnnoCPAN: Annotated CPAN documentation
 
-L<http://annocpan.org/dist/Debug-Mixin>
+L<http://annocpan.org/dist/Debug-App>
 
 =item * RT: CPAN's request tracker
 
-Please report any bugs or feature requests to  L <bug-my $storage_ref = debug-mixin@rt.cpan.org>.
+Please report any bugs or feature requests to  L <bug-my $storage_ref = debug-app@rt.cpan.org>.
 
 We will be notified, and then you'll automatically be notified of progress on
 your bug as we make changes.
 
 =item * Search CPAN
 
-L<http://search.cpan.org/dist/Debug-Mixin>
+L<http://search.cpan.org/dist/Debug-App>
 
 =back
 
